{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "hr",
  "clipboard.copy": "Kopirajte u međuspremnik",
  "clipboard.copied": "Kopirano u međuspremnik",
  "edit.link.title": "Uredi stranicu",
  "footer.previous": "Prethodno",
  "footer.next": "Sljedeće",
  "meta.comments": "Komentari",
  "meta.source": "Izvor",
  "search.placeholder": "Pretraživanje",
  "search.result.placeholder": "Unesite pojam pretraživanja",
  "search.result.none": "Ništa nije pronađeno",
  "search.result.one": "1 rezultat pretraživanja",
  "search.result.other": "# rezultata pretraživanja",
  "skip.link.title": "Preskočite na sadržaj",
  "source.link.title": "Idite u repozitorij",
  "source.revision.date": "Zadnje ažuriranje",
  "toc.title": "Sadržaj"
}[key] }}{% endmacro %}
