{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "no",
  "clipboard.copy": "Kopier til utklippstavlen",
  "clipboard.copied": "Kopiert til utklippstavlen",
  "edit.link.title": "Rediger denne siden",
  "footer.previous": "Forrige",
  "footer.next": "Neste",
  "meta.comments": "Kommentarer",
  "meta.source": "Kilde",
  "search.config.lang": "no",
  "search.placeholder": "Søk",
  "search.result.placeholder": "Skriv søkeord",
  "search.result.none": "Ingen treff",
  "search.result.one": "1 treff",
  "search.result.other": "# treff",
  "skip.link.title": "Gå til innhold",
  "source.link.title": "Gå til kilde",
  "source.revision.date": "Siste oppdatering",
  "toc.title": "Innholdsfortegnelse"
}[key] }}{% endmacro %}
