{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "sr",
  "clipboard.copy": "Копирај у клипборд",
  "clipboard.copied": "Ископирано у клипборд",
  "edit.link.title": "Уреди страницу",
  "footer.previous": "Претходно",
  "footer.next": "Следеће",
  "meta.comments": "Коментари",
  "meta.source": "Извор",
  "search.config.lang": "ru",
  "search.placeholder": "Претрага",
  "search.result.placeholder": "Унесите појам претраге",
  "search.result.none": "Нису пронађени документи",
  "search.result.one": "1 резултат претраге",
  "search.result.other": "# резултата претраге",
  "skip.link.title": "Иди на текст",
  "source.link.title": "Иди у репозиторијум",
  "source.revision.date": "Последња исправка",
  "toc.title": "Садржај"
}[key] }}{% endmacro %}
