{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "hi",
  "clipboard.copy": "क्लिपबोर्ड पर कॉपी करें",
  "clipboard.copied": "क्लिपबोर्ड पर कॉपी कर दिया गया",
  "edit.link.title": "इस पृष्ठ को संपादित करें",
  "footer.previous": "पिछला",
  "footer.next": "आगामी",
  "meta.comments": "टिप्पणियाँ",
  "meta.source": "स्रोत",
  "search.config.pipeline": " ",
  "search.placeholder": "खोज",
  "search.result.placeholder": "खोज शुरू करने के लिए टाइप करें",
  "search.result.none": "कोई मिलान डॉक्यूमेंट नहीं",
  "search.result.one": "1 मिलान डॉक्यूमेंट",
  "search.result.other": "# मिलान डाक्यूमेंट्स",
  "skip.link.title": "विषय पर बढ़ें",
  "source.link.title": "रिपॉजिटरी पर जाएं",
  "source.revision.date": "आखिरी अपडेट",
  "toc.title": "विषय - सूची"
}[key] }}{% endmacro %}
