{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "zh",
  "clipboard.copy": "复制",
  "clipboard.copied": "已复制",
  "edit.link.title": "编辑此页",
  "footer.previous": "上一页",
  "footer.next": "下一页",
  "meta.comments": "评论",
  "meta.source": "来源",
  "search.config.lang": "ja",
  "search.config.pipeline": "trimmer, stemmer",
  "search.config.separator": "[\，\。]+",
  "search.placeholder": "搜索",
  "search.result.initializer": "正在初始化搜索引擎",
  "search.result.placeholder": "键入以开始搜索",
  "search.result.none": "没有找到符合条件的结果",
  "search.result.one": "找到 1 个符合条件的结果",
  "search.result.other": "# 个符合条件的结果",
  "skip.link.title": "跳转至",
  "source.link.title": "前往 GitHub 仓库",
  "source.revision.date": "最后更新",
  "toc.title": "目录"
}[key] }}{% endmacro %}
