{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "zh-Hant",
  "clipboard.copy": "複製",
  "clipboard.copied": "已複製",
  "edit.link.title": "編輯此頁",
  "footer.previous": "上一頁",
  "footer.next": "下一頁",
  "meta.comments": "留言",
  "meta.source": "來源",
  "search.config.lang": "ja",
  "search.config.pipeline": "trimmer, stemmer",
  "search.config.separator": "[\s\-　、。，．？；]+",
  "search.placeholder": "搜尋",
  "search.result.initializer": "正在初始化搜尋引擎",
  "search.result.placeholder": "打字進行搜尋",
  "search.result.none": "沒有符合的項目",
  "search.result.one": "找到 1 個符合的項目",
  "search.result.other": "找到 # 個符合的項目",
  "skip.link.title": "跳轉到",
  "source.link.title": "前往倉庫",
  "source.revision.date": "最後更新",
  "toc.title": "目錄"
}[key] }}{% endmacro %}
