{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "tr",
  "clipboard.copy": "Kopyala",
  "clipboard.copied": "Kopyalandı",
  "edit.link.title": "Düzenle",
  "footer.previous": "Önceki",
  "footer.next": "Sonraki",
  "meta.comments": "Yorumlar",
  "meta.source": "Kaynak",
  "search.config.lang": "tr",
  "search.placeholder": "Ara",
  "search.result.placeholder": "Aramaya başlamak için yazın",
  "search.result.none": "Eşleşen doküman bulunamadı",
  "search.result.one": "1 doküman bulundu",
  "search.result.other": "# doküman bulundu",
  "skip.link.title": "Ana içeriğe geç",
  "source.link.title": "Depoya git",
  "source.revision.date": "Son Güncelleme",
  "toc.title": "İçindekiler"
}[key] }}{% endmacro %}
