{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "ja",
  "clipboard.copy": "クリップボードへコピー",
  "clipboard.copied": "コピーしました",
  "edit.link.title": "編集",
  "footer.previous": "前",
  "footer.next": "次",
  "meta.comments": "コメント",
  "meta.source": "ソース",
  "search.config.lang": "ja",
  "search.config.pipeline": "trimmer, stemmer",
  "search.config.separator": "[\s\-　、。，．]+",
  "search.placeholder": "検索",
  "search.result.placeholder": "検索キーワードを入力してください",
  "search.result.none": "何も見つかりませんでした",
  "search.result.one": "1件見つかりました",
  "search.result.other": "#件見つかりました",
  "skip.link.title": "コンテンツにスキップ",
  "source.link.title": "リポジトリへ",
  "source.revision.date": "最終更新日",
  "toc.title": "目次"
}[key] }}{% endmacro %}
